/**
 * The MeCab PHP extension
 *
 * Copyright (c) 2006-2007 Ryusuke SEKIYAMA. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any personobtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * @package     php_mecab
 * @author      Ryusuke SEKIYAMA <rsky0711@gmail.com>
 * @copyright   2006-2007 Ryusuke SEKIYAMA
 * @license     http://www.opensource.org/licenses/mit-license.php  MIT License
 * @version     SVN: $Id:$
 */

#ifndef PHP_MECAB_H
#define PHP_MECAB_H

#ifdef __cplusplus
extern "C" {
#endif

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <php.h>

#include <php_ini.h>
#include <SAPI.h>
#include <ext/standard/info.h>
#include <Zend/zend_extensions.h>

#ifdef __cplusplus
} /* extern "C" */
#endif

#include <mecab.h>

#ifdef __cplusplus
extern "C" {
#endif

extern zend_module_entry mecab_module_entry;
#define phpext_mecab_ptr &mecab_module_entry

#ifdef PHP_WIN32
#define PHP_MECAB_API __declspec(dllexport)
#else
#define PHP_MECAB_API
#endif

PHP_MINIT_FUNCTION(mecab);
PHP_MSHUTDOWN_FUNCTION(mecab);
PHP_MINFO_FUNCTION(mecab);

#ifdef ZTS
#include "TSRM.h"
#endif

#define FREE_RESOURCE(resource) zend_list_delete(Z_LVAL_P(resource))

ZEND_BEGIN_MODULE_GLOBALS(mecab)
	char *default_rcfile;
	char *default_dicdir;
	char *default_userdic;
ZEND_END_MODULE_GLOBALS(mecab)

#ifdef ZTS
#define MECAB_G(v) TSRMG(mecab_globals_id, zend_mecab_globals *, v)
#else
#define MECAB_G(v) (mecab_globals.v)
#endif

/* Get MeCab library version */
PHP_FUNCTION(mecab_version);
/* Wakati-Gaki function */
PHP_FUNCTION(mecab_split);
/* MeCab API wrappers */
PHP_FUNCTION(mecab_new);
PHP_FUNCTION(mecab_destroy);
PHP_FUNCTION(mecab_sparse_tostr);
PHP_FUNCTION(mecab_sparse_tonode);
PHP_FUNCTION(mecab_nbest_sparse_tostr);
PHP_FUNCTION(mecab_nbest_init);
PHP_FUNCTION(mecab_nbest_next_tostr);
PHP_FUNCTION(mecab_nbest_next_tonode);
PHP_FUNCTION(mecab_format_node);
PHP_FUNCTION(mecab_dictionary_info);
/* Dumper for mecab_node */
PHP_FUNCTION(mecab_node_toarray);
PHP_FUNCTION(mecab_node_tostring);
/* Getters for mecab_node */
PHP_FUNCTION(mecab_node_prev);
PHP_FUNCTION(mecab_node_next);
PHP_FUNCTION(mecab_node_enext);
PHP_FUNCTION(mecab_node_bnext);
PHP_FUNCTION(mecab_node_rpath);
PHP_FUNCTION(mecab_node_lpath);
PHP_FUNCTION(mecab_node_begin_node_list);
PHP_FUNCTION(mecab_node_end_node_list);
PHP_FUNCTION(mecab_node_surface);
PHP_FUNCTION(mecab_node_feature);
PHP_FUNCTION(mecab_node_id);
PHP_FUNCTION(mecab_node_length);
PHP_FUNCTION(mecab_node_rlength);
PHP_FUNCTION(mecab_node_rcattr);
PHP_FUNCTION(mecab_node_lcattr);
PHP_FUNCTION(mecab_node_posid);
PHP_FUNCTION(mecab_node_char_type);
PHP_FUNCTION(mecab_node_stat);
PHP_FUNCTION(mecab_node_isbest);
PHP_FUNCTION(mecab_node_sentence_length);
PHP_FUNCTION(mecab_node_alpha);
PHP_FUNCTION(mecab_node_beta);
PHP_FUNCTION(mecab_node_prob);
PHP_FUNCTION(mecab_node_wcost);
PHP_FUNCTION(mecab_node_cost);
/* Getters for mecab_path */
PHP_FUNCTION(mecab_path_rnext);
PHP_FUNCTION(mecab_path_lnext);
PHP_FUNCTION(mecab_path_rnode);
PHP_FUNCTION(mecab_path_lnode);
PHP_FUNCTION(mecab_path_prob);
PHP_FUNCTION(mecab_path_cost);

#ifdef ZEND_ENGINE_2
PHP_METHOD(MeCab_Node, __construct);
PHP_METHOD(MeCab_Path, __construct);
/* Overloading implementations for mecab_node */
PHP_METHOD(MeCab_Node, __get);
PHP_METHOD(MeCab_Node, __isset);
/* IteratorAggregate implementations for mecab_node */
PHP_METHOD(MeCab_Node, getIterator);
PHP_METHOD(MeCab_Node, setTraverse);
PHP_METHOD(MeCab_Node, getBeginNodeList);
PHP_METHOD(MeCab_Node, getEndNodeList);
/* Iterator implementations for mecab_node */
PHP_METHOD(MeCab_NodeIterator, __construct);
PHP_METHOD(MeCab_NodeIterator, current);
PHP_METHOD(MeCab_NodeIterator, key);
PHP_METHOD(MeCab_NodeIterator, valid);
PHP_METHOD(MeCab_NodeIterator, rewind);
PHP_METHOD(MeCab_NodeIterator, next);
/* Overloading implementations for mecab_path */
PHP_METHOD(MeCab_Path, __get);
PHP_METHOD(MeCab_Path, __isset);
#endif

#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /* PHP_MECAB_H */


/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
